/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'image2', 'he', {
	alt: 'טקסט חלופי',
	btnUpload: 'שליחה לשרת',
	captioned: 'כותרת תמונה',
	captionPlaceholder: 'כותרת',
	infoTab: 'מידע על התמונה',
	lockRatio: 'נעילת היחס',
	menu: 'תכונות התמונה',
	pathName: 'תמונה',
	pathNameCaption: 'כותרת',
	resetSize: 'איפוס הגודל',
	resizer: 'לחץ וגרור לשינוי הגודל',
	title: 'מאפייני התמונה',
	uploadTab: 'העלאה',
	urlMissing: 'כתובת התמונה חסרה.',
	altMissing: 'Alternative text is missing.' // MISSING
} );
